.. drf-cached-instances documentation master file, created by
   sphinx-quickstart on Mon Jul 21 13:24:51 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

Contents
========

.. toctree::
   :maxdepth: 2

   project
   installation
   usage
   contributing
   authors
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
